/**
 * On document ready, set up handlers.
 */
jQuery('document').ready(function() {

	// Check to see if we need to show the form when payment method is changed.
	jQuery('form.checkout').on(
		'click',
		'input[name="payment_method"]',
		function() {
			jQuery('#paymill_payment_id').change();
		}
	);
	// Show the frame if "New card" is selected.
    jQuery('body').on('change', '#paymill_payment_id', function() {
        if ( jQuery('#paymill_payment_id').val() == '' ) {
            jQuery('#paymill_new_card_form').slideDown(function() {
            	if (jQuery('#paymill_new_card_form iframe').length < 1) {
					paymill.embedFrame(document.getElementById('paymill_new_card_form'), { lang: wc_paymill.locale }, function(error) {
						// Remove any existing tokens.
						if (error) {
							console.log(error.apierror, error.message);
						}
					});
            	}
            });
        } else {
            jQuery('#paymill_new_card_form').slideUp();
        }
    })
    // Hook up our submit handler.
    jQuery('form.checkout').on('checkout_place_order_paymill', function () {
        return paymill_process_checkout(this);
    });
    // Show the form if required.
    jQuery('#paymill_payment_id').change();
});

/**
 * Processes the form submit action.
 *
 * Lets checkout proceed if we have a payment ID, or a token already. If not,
 * asks the frame for a token and waits for it to be returned.
 */
function paymill_process_checkout(dom_element) {

	// Set the cancel button, otherwise it defaults to German
	paymill.config( '3ds_cancel_label', wc_paymill.threeds_cancel_label );

	// If we have a new token, replace the token to be submitted and submit.
	if ( jQuery( '#new_paymill_token' ).length > 0) {
		var token = jQuery('#new_paymill_token').val();
		jQuery('#paymill_token').remove();
		jQuery('#new_paymill_token').remove();
		jQuery('form.checkout').append('<input type="hidden" name="paymill_token" id="paymill_token" value="' + token + '">');
		return true;
	} else {
		// Otherwise make sure we do not have a potentially stale token.
		jQuery('#paymill_token').remove();
	}

    // Let WooCommerce submit the form if we have a payment ID selected
    if ( jQuery('#paymill_payment_id').length > 0 && jQuery('#paymill_payment_id').val() != '' ) {
        return true;
    }

	// Try and get a token.
    paymill.createTokenViaFrame(
    	{
        	amount_int: jQuery('#paymill_order_total').val(),
	        currency: PAYMILL_CURRENCY,
        },
        paymill_response_handler
    );

    // Don't let WooCommerce submit the form yet - the callback handler will do it
    return false;
}

/**
 * Handles the callback from the payment frame.
 */
function paymill_response_handler(error, result) {
	// Remove any existing tokens.
    jQuery('#new_paymill_token, #paymill_token').remove();
    if ( error || result.token.length < 1) {
        jQuery("#paymill_messages").show();
    } else {
        // Create the paymill token and submit the form
        jQuery('form.checkout').append('<input type="hidden" name="new_paymill_token" id="new_paymill_token" value="' + result.token + '">');
        jQuery('form.checkout').submit();
    }
}
